function AR = GetEventAR(ReqFileName, FirmFileName, IndexFileName)
% the fubnction takes names of the request file, firm prices file, and index
% (s&p) prices file
% the request file has one event per company
% the function outputs the array AR with the two columns: 
% event id, AR at the time of event 
% the function has to work from the same directory, where the files are

% import request file

ReqF = importdata(ReqFileName,';');

% import company file

Firm = importdata(FirmFileName,';');

% import index file

Index = importdata(IndexFileName,';');

% make correct dates for the company file
[kf, ~] = size(Firm.textdata);

FirmDateNumbers = zeros(kf, 1);

for i = 1:kf
    a = Firm.textdata(i, 2);
    FirmDateNumbers(i) = GetDateNum(a{1});
end
    
% make correct dates for the index

[ki, ~] = size(Index.textdata);
IndexDateNumbers = zeros(ki, 1);
for i = 1:ki
    a = Index.textdata(i, 2);
    IndexDateNumbers(i) = GetDateNum(a{1});
end

% calculate returns for the company file and create data structure with 
% the company name, date number, return
% create index file with the company name, start position

comps = struct('Name', {}, 'dateNum', {}, 'return', {});
compIndex = struct('Name', {}, 'begin', {});
com = '';
count = 0;
countInd = 0;

for i = 1:kf
    a = Firm.textdata(i, 1);
    if(~strcmp(a{1}, com))
        com = a{1};      
        countInd = countInd+1;
        compIndex(countInd).Name = com;
        compIndex(countInd).begin = count + 1;
    else
        count = count + 1;
        comps(count).Name = com;
        comps(count).dateNum = FirmDateNumbers(i);
        comps(count).return = (Firm.data(i, 1) - Firm.data(i-1, 1))/Firm.data(i-1, 1);
    end
end
         
% calculate returns for the index; create structure with the date number 
% and return for the index

sp = struct('dateNum', {}, 'return', {}); 

for i = 2:ki
    sp(i-1).dateNum = IndexDateNumbers(i);
    sp(i-1).return = (Index.data(i,1) - Index.data(i-1,1))/Index.data(i-1,1);
end

ki = ki - 1;
% create data structure for the request file
 r = struct('ID', {}, 'firmName',{}, 'eventDate',{}, 'eventWindowLeft',{}, 'eventWindowRight',{},...
     'estWindowEnd',{},'estWindowLength',{});
[kr, ~] = size(ReqF.textdata); 

for i = 1:kr
    r(i).ID = ReqF.textdata(i, 1);
    r(i).firmName = ReqF.textdata(i, 2);
    a = ReqF.textdata(i, 4);
    a = a{1};
    r(i).eventDate = GetDateNum(a);
    r(i).eventWindowLeft = ReqF.data(i, 1);
    r(i).eventWindowRight = ReqF.data(i, 2);  
    r(i).estWindowEnd = ReqF.data(i, 3);
    r(i).estWindowLength = ReqF.data(i, 4);
    
end

% loop by the request file: take company and date; find this company and date in 
% company file; find this date in index file; 

AR = zeros(kr, 2);
for i = 1:kr
    a = r(i).ID;
    c = str2num(a{1}); % transform ID into number
    AR(i, 1) = c;
    name = r(i).firmName; % take from the request file
    date = r(i).eventDate; % take from the request file
    % find the company in the compIndex file
    for j = 1:countInd
        if(strcmp(name, compIndex(j).Name))
            break;
        end
    end
    
    pos = compIndex(j).begin;
    % starting from the position pos, look in dates in the comps file
    for k = pos:count
        if(date == comps(k).dateNum)
            break;
        end
    end
    
    % k is the index of the event in the comps file
    % this is window in the comps file
    windowEnd = k - r(i).estWindowEnd;
    windowBeg = windowEnd - r(i).estWindowLength +1;
    
    % find index of the event in the sp file
    for j = 1:ki
        if(sp(j).dateNum == date)
            break;
        end
    end
    
    % j is index of the event in the sp file
    % get the window in the sp file
    windowEnd_ = j - r(i).estWindowEnd;
    windowBeg_ = windowEnd_ - r(i).estWindowLength +1;
    
    x = zeros(r(i).estWindowLength, 1);
    y = zeros(r(i).estWindowLength, 1);
    for ii = 1:r(i).estWindowLength
        x(ii)= sp(windowBeg_+ii -1).return;
        y(ii) = comps(windowBeg + ii -1).return;
    end
   
    
    X = [ones(size(x)) x];
    
    [b, bint] = regress(y,X);
    
    %figure;
    %plot(x, y, 'o')
    
    rI = sp(j).return;
    predictedReturn = b(1) + b(2)*rI;
    AR(i, 2) = - predictedReturn + comps(k).return; 
 
end
%%

AR = sortrows(AR, 1);
end

